@@ -30,7 +30,7 @@ else:
 
 
 from bitarray import (bitarray, frozenbitarray,
-                      bitdiff, bits2bytes, __version__)
+                      bitdiff, bits2bytes, _sysinfo, __version__)
 
 
 tests = []
@@ -735,7 +735,7 @@ class MiscTests(unittest.TestCase, Util):
                 self.assertEQUAL(a, b)
 
     def test_overflow(self):
-        if tuple.__itemsize__ == 8:
+        if _sysinfo()[0] == 8:
             return
 
         self.assertRaises(OverflowError, bitarray.__new__,
@@ -2373,11 +2373,8 @@ tests.append(TestsFrozenbitarray)
 # ---------------------------------------------------------------------------
 
 def run(verbosity=1, repeat=1):
-    try:
-        import bitarray.test_util as btu
-        tests.extend(btu.tests)
-    except ImportError:
-        print("WARNING: could not import bitarray.test_util")
+    import bitarray.test_util as btu
+    tests.extend(btu.tests)
 
     print('bitarray is installed in: %s' % os.path.dirname(__file__))
     print('bitarray version: %s' % __version__)
